@@ -1,6 +1,7 @@
 import os
 import json
 import requests
+from .log_keeper import *
 
 
 # def reg_no_ml_options(data):
@@ -50,39 +51,48 @@ import requests
 
 def reg_ml(data, ml_options):
     datasetUploadPath = ml_options["datasetUploadPath"]
-    if os.path.exists(ml_options["credPath"]):
-                f = open(ml_options["credPath"])
-                creds = json.load(f)
-                print(creds)
-    else:
-        print("Credential file path invalid.")
-        exit()
-    data.update({"amlCred": json.dumps(creds), "datasetUploadPath": datasetUploadPath})
+    try:
+        if os.path.exists(ml_options["credPath"]):
+                    f = open(ml_options["credPath"])
+                    creds = json.load(f)
+                    print(creds)
+        else:
+            print("Credential file path invalid.")
+            exit()
+        data.update({"amlCred": json.dumps(creds), "datasetUploadPath": datasetUploadPath})
+    except Exception as e:
+        logger.error(str(e))
     return data
 
 def fetch_ml(data, ml_options):
     dataPath = ml_options["dataPath"]
-    if os.path.exists(ml_options["credPath"]):
-                f = open(ml_options["credPath"])
-                creds = json.load(f)
-                print(creds)
-    else:
-        print("Credential file path invalid.")
-        exit()
-    data.update({"amlCred": json.dumps(creds), "dataPath": dataPath})
+    try:
+        if os.path.exists(ml_options["credPath"]):
+                    f = open(ml_options["credPath"])
+                    creds = json.load(f)
+                    print(creds)
+        else:
+            print("Credential file path invalid.")
+            exit()
+        data.update({"amlCred": json.dumps(creds), "dataPath": dataPath})
+    except Exception as e:
+        logger.error(str(e))
     return data
 
 def model_request(url, kwargs, data, ml_options, files):
     insertionType = data.get("datasetinsertionType", None)
-    if insertionType == "Manual":
-        data = reg_ml(data, ml_options)
-        model = requests.post(url, data=data, files=files, headers=kwargs['headers'])
-    elif insertionType == "AzureML":
-        data = fetch_ml(data, ml_options)
-        data.update(files)
-        model = requests.post(url, data=data, headers=kwargs['headers'])
-    else:
-        data.update({"datasetinsertionType":"Manual"})
-        model = requests.post(url, data=data, files=files, headers=kwargs['headers'])
+    try:
+        if insertionType == "Manual":
+            data = reg_ml(data, ml_options)
+            model = requests.post(url, data=data, files=files, headers=kwargs['headers'])
+        elif insertionType == "AzureML":
+            data = fetch_ml(data, ml_options)
+            data.update(files)
+            model = requests.post(url, data=data, headers=kwargs['headers'])
+        else:
+            data.update({"datasetinsertionType":"Manual"})
+            model = requests.post(url, data=data, files=files, headers=kwargs['headers'])
+    except Exception as e:
+        logger.error(str(e))
     return model
     
\ No newline at end of file
